@@ -1007,6 +1007,8 @@ public abstract class AbstractArchiver
         {
             cleanUp();
         }
+
+        postCreateArchive();
     }
 
     protected boolean hasVirtualFiles()
@@ -1036,6 +1038,21 @@ public abstract class AbstractArchiver
     {
     }
 
+    /**
+     * This method is called after the archive creation
+     * completes successfully (no exceptions are thrown).
+     *
+     * Subclasses may override this method in order to
+     * augment or validate the archive after it is
+     * created.
+     *
+     * @since 3.6
+     */
+    protected void postCreateArchive()
+        throws ArchiverException, IOException
+    {
+    }
+
     protected abstract String getArchiveType();
 
     private void addCloseable( Object maybeCloseable )
